@@ -22,17 +22,12 @@ import (
 	"os/signal"
 	"path/filepath"
 	"regexp"
-	"runtime"
 	"strings"
 	"syscall"
 
 	"github.com/abiosoft/readline"
-	sqle "github.com/dolthub/go-mysql-server"
-	"github.com/dolthub/go-mysql-server/auth"
 	"github.com/dolthub/go-mysql-server/sql"
-	"github.com/dolthub/go-mysql-server/sql/analyzer"
 	"github.com/dolthub/go-mysql-server/sql/expression"
-	"github.com/dolthub/go-mysql-server/sql/information_schema"
 	"github.com/dolthub/go-mysql-server/sql/parse"
 	"github.com/dolthub/go-mysql-server/sql/plan"
 	"github.com/dolthub/ishell"
@@ -40,9 +35,9 @@ import (
 	"github.com/dolthub/vitess/go/vt/vterrors"
 	"github.com/fatih/color"
 	"github.com/flynn-archive/go-shlex"
-	"gopkg.in/src-d/go-errors.v1"
 
 	"github.com/dolthub/dolt/go/cmd/dolt/cli"
+	"github.com/dolthub/dolt/go/cmd/dolt/commands/engine"
 	"github.com/dolthub/dolt/go/cmd/dolt/errhand"
 	eventsapi "github.com/dolthub/dolt/go/gen/proto/dolt/services/eventsapi/v1alpha1"
 	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb"
@@ -51,15 +46,9 @@ import (
 	dsqle "github.com/dolthub/dolt/go/libraries/doltcore/sqle"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/dsess"
 	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/dtables"
-	"github.com/dolthub/dolt/go/libraries/doltcore/table/editor"
 	"github.com/dolthub/dolt/go/libraries/utils/argparser"
-	"github.com/dolthub/dolt/go/libraries/utils/config"
-	"github.com/dolthub/dolt/go/libraries/utils/filesys"
 	"github.com/dolthub/dolt/go/libraries/utils/iohelp"
 	"github.com/dolthub/dolt/go/libraries/utils/osutil"
-	"github.com/dolthub/dolt/go/libraries/utils/tracing"
-	"github.com/dolthub/dolt/go/store/datas"
-	"github.com/dolthub/dolt/go/store/types"
 )
 
 type batchMode int64
@@ -199,7 +188,7 @@ func (cmd SqlCmd) Exec(ctx context.Context, commandStr string, args []string, dE
 		return true, nil
 	})
 
-	format := FormatTabular
+	format := engine.FormatTabular
 	if formatSr, ok := apr.GetValue(FormatFlag); ok {
 		var verr errhand.VerboseError
 		format, verr = GetResultFormat(formatSr)
@@ -256,7 +245,7 @@ func listSavedQueriesMode(
 	mrEnv *env.MultiRepoEnv,
 	initialRoots map[string]*doltdb.RootValue,
 	currentDb string,
-	format resultFormat,
+	format engine.PrintResultFormat,
 	usage cli.UsagePrinter,
 ) int {
 	hasQC, err := initialRoots[currentDb].HasTable(ctx, doltdb.DoltQueryCatalogTableName)
@@ -280,7 +269,7 @@ func savedQueryMode(
 	initialRoots map[string]*doltdb.RootValue,
 	savedQueryName string,
 	currentDb string,
-	format resultFormat,
+	format engine.PrintResultFormat,
 	usage cli.UsagePrinter,
 ) int {
 	sq, err := dtables.RetrieveFromQueryCatalog(ctx, initialRoots[currentDb], savedQueryName)
@@ -300,7 +289,7 @@ func queryMode(
 	apr *argparser.ArgParseResults,
 	query string,
 	currentDb string,
-	format resultFormat,
+	format engine.PrintResultFormat,
 	usage cli.UsagePrinter,
 ) int {
 	batchMode := apr.Contains(BatchFlag)
@@ -368,14 +357,10 @@ func getMultiRepoEnv(ctx context.Context, apr *argparser.ArgParseResults, dEnv *
 func execShell(
 	ctx context.Context,
 	mrEnv *env.MultiRepoEnv,
-	format resultFormat,
+	format engine.PrintResultFormat,
 	initialDb string,
 ) errhand.VerboseError {
-	dbs, err := CollectDBs(ctx, mrEnv)
-	if err != nil {
-		return errhand.VerboseErrorFromError(err)
-	}
-	se, err := newSqlEngine(ctx, mrEnv.Config(), mrEnv.FileSystem(), format, initialDb, dbs...)
+	se, err := engine.NewSqlEngine(ctx, mrEnv, format, initialDb, true)
 	if err != nil {
 		return errhand.VerboseErrorFromError(err)
 	}
@@ -392,31 +377,21 @@ func execBatch(
 	continueOnErr bool,
 	mrEnv *env.MultiRepoEnv,
 	batchInput io.Reader,
-	format resultFormat,
+	format engine.PrintResultFormat,
 	initialDb string,
 ) errhand.VerboseError {
-	dbs, err := CollectDBs(ctx, mrEnv)
+	se, err := engine.NewSqlEngine(ctx, mrEnv, format, initialDb, false)
 	if err != nil {
 		return errhand.VerboseErrorFromError(err)
 	}
 
-	se, err := newSqlEngine(ctx, mrEnv.Config(), mrEnv.FileSystem(), format, initialDb, dbs...)
-	if err != nil {
-		return errhand.VerboseErrorFromError(err)
-	}
-
-	sqlCtx, err := se.newContext(ctx)
+	sqlCtx, err := se.NewContext(ctx)
 	if err != nil {
 		return errhand.VerboseErrorFromError(err)
 	}
 
 	// In batch mode, we need to set a couple flags on the session to prevent constant flushes to disk
 	dsess.DSessFromSess(sqlCtx.Session).EnableBatchedMode()
-	err = sqlCtx.Session.SetSessionVariable(sqlCtx, sql.AutoCommitSessionVar, false)
-	if err != nil {
-		return errhand.VerboseErrorFromError(err)
-	}
-
 	err = runBatchMode(sqlCtx, se, batchInput, continueOnErr)
 	if err != nil {
 		// If we encounter an error, attempt to flush what we have so far to disk before exiting
@@ -436,19 +411,15 @@ func execMultiStatements(
 	continueOnErr bool,
 	mrEnv *env.MultiRepoEnv,
 	batchInput io.Reader,
-	format resultFormat,
+	format engine.PrintResultFormat,
 	initialDb string,
 ) errhand.VerboseError {
-	dbs, err := CollectDBs(ctx, mrEnv)
-	if err != nil {
-		return errhand.VerboseErrorFromError(err)
-	}
-	se, err := newSqlEngine(ctx, mrEnv.Config(), mrEnv.FileSystem(), format, initialDb, dbs...)
+	se, err := engine.NewSqlEngine(ctx, mrEnv, format, initialDb, true)
 	if err != nil {
 		return errhand.VerboseErrorFromError(err)
 	}
 
-	sqlCtx, err := se.newContext(ctx)
+	sqlCtx, err := se.NewContext(ctx)
 	if err != nil {
 		return errhand.VerboseErrorFromError(err)
 	}
@@ -462,52 +433,19 @@ func execMultiStatements(
 	return errhand.VerboseErrorFromError(err)
 }
 
-func newDatabase(name string, dEnv *env.DoltEnv) dsqle.Database {
-	opts := editor.Options{
-		Deaf: dEnv.DbEaFactory(),
-	}
-	return dsqle.NewDatabase(name, dEnv.DbData(), opts)
-}
-
-// newReplicaDatabase creates a new dsqle.ReadReplicaDatabase. If the doltdb.SkipReplicationErrorsKey global variable is set,
-// skip errors related to database construction only and return a partially functional dsqle.ReadReplicaDatabase
-// that will log warnings when attempting to perform replica commands.
-func newReplicaDatabase(ctx context.Context, name string, remoteName string, dEnv *env.DoltEnv) (dsqle.ReadReplicaDatabase, error) {
-	opts := editor.Options{
-		Deaf: dEnv.DbEaFactory(),
-	}
-
-	db := dsqle.NewDatabase(name, dEnv.DbData(), opts)
-
-	rrd, err := dsqle.NewReadReplicaDatabase(ctx, db, remoteName, dEnv)
-	if err != nil {
-		err = fmt.Errorf("%w from remote '%s'; %s", dsqle.ErrFailedToLoadReplicaDB, remoteName, err.Error())
-		if !dsqle.SkipReplicationWarnings() {
-			return dsqle.ReadReplicaDatabase{}, err
-		}
-		cli.Println(err)
-		return dsqle.ReadReplicaDatabase{Database: db}, nil
-	}
-	return rrd, nil
-}
-
 func execQuery(
 	ctx context.Context,
 	mrEnv *env.MultiRepoEnv,
 	query string,
-	format resultFormat,
+	format engine.PrintResultFormat,
 	initialDb string,
 ) errhand.VerboseError {
-	dbs, err := CollectDBs(ctx, mrEnv)
-	if err != nil {
-		return errhand.VerboseErrorFromError(err)
-	}
-	se, err := newSqlEngine(ctx, mrEnv.Config(), mrEnv.FileSystem(), format, initialDb, dbs...)
+	se, err := engine.NewSqlEngine(ctx, mrEnv, format, initialDb, true)
 	if err != nil {
 		return errhand.VerboseErrorFromError(err)
 	}
 
-	sqlCtx, err := se.newContext(ctx)
+	sqlCtx, err := se.NewContext(ctx)
 	if err != nil {
 		return errhand.VerboseErrorFromError(err)
 	}
@@ -518,7 +456,7 @@ func execQuery(
 	}
 
 	if rowIter != nil {
-		err = PrettyPrintResults(sqlCtx, se.resultFormat, sqlSch, rowIter, HasTopLevelOrderByClause(query))
+		err = engine.PrettyPrintResults(sqlCtx, se.GetReturnFormat(), sqlSch, rowIter, HasTopLevelOrderByClause(query))
 		if err != nil {
 			return errhand.VerboseErrorFromError(err)
 		}
@@ -527,93 +465,6 @@ func execQuery(
 	return nil
 }
 
-func getPushOnWriteHook(ctx context.Context, dEnv *env.DoltEnv) (*doltdb.PushOnWriteHook, error) {
-	_, val, ok := sql.SystemVariables.GetGlobal(dsqle.ReplicateToRemoteKey)
-	if !ok {
-		return nil, sql.ErrUnknownSystemVariable.New(dsqle.ReplicateToRemoteKey)
-	} else if val == "" {
-		return nil, nil
-	}
-
-	remoteName, ok := val.(string)
-	if !ok {
-		return nil, sql.ErrInvalidSystemVariableValue.New(val)
-	}
-
-	remotes, err := dEnv.GetRemotes()
-	if err != nil {
-		return nil, err
-	}
-
-	rem, ok := remotes[remoteName]
-	if !ok {
-		return nil, fmt.Errorf("%w: '%s'", env.ErrRemoteNotFound, remoteName)
-	}
-
-	ddb, err := rem.GetRemoteDB(ctx, types.Format_Default)
-	if err != nil {
-		return nil, err
-	}
-
-	pushHook := doltdb.NewPushOnWriteHook(ddb, dEnv.TempTableFilesDir())
-	return pushHook, nil
-}
-
-// GetCommitHooks creates a list of hooks to execute on database commit. If doltdb.SkipReplicationErrorsKey is set,
-// replace misconfigured hooks with doltdb.LogHook instances that prints a warning when trying to execute.
-func GetCommitHooks(ctx context.Context, dEnv *env.DoltEnv) ([]datas.CommitHook, error) {
-	postCommitHooks := make([]datas.CommitHook, 0)
-
-	if hook, err := getPushOnWriteHook(ctx, dEnv); err != nil {
-		err = fmt.Errorf("failure loading hook; %w", err)
-		if dsqle.SkipReplicationWarnings() {
-			postCommitHooks = append(postCommitHooks, doltdb.NewLogHook([]byte(err.Error()+"\n")))
-		} else {
-			return nil, err
-		}
-	} else if hook != nil {
-		postCommitHooks = append(postCommitHooks, hook)
-	}
-
-	return postCommitHooks, nil
-}
-
-// CollectDBs takes a MultiRepoEnv and creates Database objects from each environment and returns a slice of these
-// objects.
-func CollectDBs(ctx context.Context, mrEnv *env.MultiRepoEnv) ([]dsqle.SqlDatabase, error) {
-	var dbs []dsqle.SqlDatabase
-	var db dsqle.SqlDatabase
-	err := mrEnv.Iter(func(name string, dEnv *env.DoltEnv) (stop bool, err error) {
-		postCommitHooks, err := GetCommitHooks(ctx, dEnv)
-		if err != nil {
-			return true, err
-		}
-		dEnv.DoltDB.SetCommitHooks(ctx, postCommitHooks)
-
-		db = newDatabase(name, dEnv)
-
-		if _, remote, ok := sql.SystemVariables.GetGlobal(dsqle.ReadReplicaRemoteKey); ok && remote != "" {
-			remoteName, ok := remote.(string)
-			if !ok {
-				return true, sql.ErrInvalidSystemVariableValue.New(remote)
-			}
-			db, err = newReplicaDatabase(ctx, name, remoteName, dEnv)
-			if err != nil {
-				return true, err
-			}
-		}
-
-		dbs = append(dbs, db)
-		return false, nil
-	})
-
-	if err != nil {
-		return nil, err
-	}
-
-	return dbs, nil
-}
-
 func formatQueryError(message string, err error) errhand.VerboseError {
 	const (
 		maxStatementLen     = 128
@@ -673,18 +524,18 @@ func formatQueryError(message string, err error) errhand.VerboseError {
 	}
 }
 
-func GetResultFormat(format string) (resultFormat, errhand.VerboseError) {
+func GetResultFormat(format string) (engine.PrintResultFormat, errhand.VerboseError) {
 	switch strings.ToLower(format) {
 	case "tabular":
-		return FormatTabular, nil
+		return engine.FormatTabular, nil
 	case "csv":
-		return FormatCsv, nil
+		return engine.FormatCsv, nil
 	case "json":
-		return FormatJson, nil
+		return engine.FormatJson, nil
 	case "null":
-		return FormatNull, nil
+		return engine.FormatNull, nil
 	default:
-		return FormatTabular, errhand.BuildDError("Invalid argument for --result-format. Valid values are tabular, csv, json").Build()
+		return engine.FormatTabular, errhand.BuildDError("Invalid argument for --result-format. Valid values are tabular, csv, json").Build()
 	}
 }
 
@@ -769,7 +620,7 @@ func saveQuery(ctx context.Context, root *doltdb.RootValue, query string, name s
 }
 
 // runMultiStatementMode alows for the execution of more than one query, but it doesn't attempt any batch optimizations
-func runMultiStatementMode(ctx *sql.Context, se *sqlEngine, input io.Reader, continueOnErr bool) error {
+func runMultiStatementMode(ctx *sql.Context, se *engine.SqlEngine, input io.Reader, continueOnErr bool) error {
 	scanner := NewSqlStatementScanner(input)
 
 	var query string
@@ -796,7 +647,7 @@ func runMultiStatementMode(ctx *sql.Context, se *sqlEngine, input io.Reader, con
 			}
 
 			if rowIter != nil {
-				err = PrettyPrintResults(ctx, se.resultFormat, sqlSch, rowIter, HasTopLevelOrderByClause(query))
+				err = engine.PrettyPrintResults(ctx, se.GetReturnFormat(), sqlSch, rowIter, HasTopLevelOrderByClause(query))
 				if err != nil {
 					return errhand.VerboseErrorFromError(err)
 				}
@@ -822,7 +673,7 @@ func runMultiStatementMode(ctx *sql.Context, se *sqlEngine, input io.Reader, con
 }
 
 // runBatchMode processes queries until EOF. The Root of the sqlEngine may be updated.
-func runBatchMode(ctx *sql.Context, se *sqlEngine, input io.Reader, continueOnErr bool) error {
+func runBatchMode(ctx *sql.Context, se *engine.SqlEngine, input io.Reader, continueOnErr bool) error {
 	scanner := NewSqlStatementScanner(input)
 
 	var query string
@@ -864,10 +715,10 @@ func runBatchMode(ctx *sql.Context, se *sqlEngine, input io.Reader, continueOnEr
 
 // runShell starts a SQL shell. Returns when the user exits the shell. The Root of the sqlEngine may
 // be updated by any queries which were processed.
-func runShell(ctx context.Context, se *sqlEngine, mrEnv *env.MultiRepoEnv) error {
+func runShell(ctx context.Context, se *engine.SqlEngine, mrEnv *env.MultiRepoEnv) error {
 	_ = iohelp.WriteLine(cli.CliOut, welcomeMsg)
 
-	sqlCtx, err := se.newContext(ctx)
+	sqlCtx, err := se.NewContext(ctx)
 	if err != nil {
 		return err
 	}
@@ -957,7 +808,7 @@ func runShell(ctx context.Context, se *sqlEngine, mrEnv *env.MultiRepoEnv) error
 			subCtx, stop := signal.NotifyContext(ctx, os.Interrupt, syscall.SIGTERM)
 			defer stop()
 
-			sqlCtx, err = se.newContext(subCtx)
+			sqlCtx, err = se.NewContext(subCtx)
 			if err != nil {
 				shell.Println(color.RedString(err.Error()))
 				return false
@@ -967,7 +818,7 @@ func runShell(ctx context.Context, se *sqlEngine, mrEnv *env.MultiRepoEnv) error
 				verr := formatQueryError("", err)
 				shell.Println(verr.Verbose())
 			} else if rowIter != nil {
-				err = PrettyPrintResults(sqlCtx, se.resultFormat, sqlSch, rowIter, HasTopLevelOrderByClause(query))
+				err = engine.PrettyPrintResults(sqlCtx, se.GetReturnFormat(), sqlSch, rowIter, HasTopLevelOrderByClause(query))
 				if err != nil {
 					shell.Println(color.RedString(err.Error()))
 				}
@@ -1108,7 +959,7 @@ func prepend(s string, ss []string) []string {
 
 // Processes a single query. The Root of the sqlEngine will be updated if necessary.
 // Returns the schema and the row iterator for the results, which may be nil, and an error if one occurs.
-func processQuery(ctx *sql.Context, query string, se *sqlEngine) (sql.Schema, sql.RowIter, error) {
+func processQuery(ctx *sql.Context, query string, se *engine.SqlEngine) (sql.Schema, sql.RowIter, error) {
 	sqlStatement, err := sqlparser.Parse(query)
 	if err == sqlparser.ErrEmpty {
 		// silently skip empty statements
@@ -1119,7 +970,7 @@ func processQuery(ctx *sql.Context, query string, se *sqlEngine) (sql.Schema, sq
 
 	switch s := sqlStatement.(type) {
 	case *sqlparser.Use:
-		sch, ri, err := se.query(ctx, query)
+		sch, ri, err := se.Query(ctx, query)
 		if err != nil {
 			return nil, nil, err
 		}
@@ -1130,7 +981,7 @@ func processQuery(ctx *sql.Context, query string, se *sqlEngine) (sql.Schema, sq
 		cli.Println("Database changed")
 		return sch, nil, err
 	case *sqlparser.MultiAlterDDL, *sqlparser.Set, *sqlparser.Commit:
-		_, ri, err := se.query(ctx, query)
+		_, ri, err := se.Query(ctx, query)
 		if err != nil {
 			return nil, nil, err
 		}
@@ -1148,16 +999,25 @@ func processQuery(ctx *sql.Context, query string, se *sqlEngine) (sql.Schema, sq
 				return nil, nil, fmt.Errorf("Error parsing DDL: %v.", err.Error())
 			}
 		}
-		return se.ddl(ctx, s, query)
+
+		_, ri, err := se.Query(ctx, query)
+		if err != nil {
+			return nil, nil, err
+		}
+		_, err = sql.RowIterToRows(ctx, ri)
+		if err != nil {
+			return nil, nil, err
+		}
+		return nil, nil, nil
 	case *sqlparser.DBDDL:
-		return se.dbddl(ctx, s, query)
+		return se.Dbddl(ctx, s, query)
 	case *sqlparser.Load:
 		if s.Local {
 			return nil, nil, fmt.Errorf("LOCAL supported only in sql-server mode")
 		}
-		return se.query(ctx, query)
+		return se.Query(ctx, query)
 	default:
-		return se.query(ctx, query)
+		return se.Query(ctx, query)
 	}
 }
 
@@ -1187,9 +1047,9 @@ func (s *stats) shouldFlush() bool {
 	return s.unflushedEdits >= maxBatchSize
 }
 
-func flushBatchedEdits(ctx *sql.Context, se *sqlEngine) error {
-	err := se.iterDBs(func(_ string, db dsqle.SqlDatabase) (bool, error) {
-		_, rowIter, err := se.engine.Query(ctx, "COMMIT;")
+func flushBatchedEdits(ctx *sql.Context, se *engine.SqlEngine) error {
+	err := se.IterDBs(func(_ string, db dsqle.SqlDatabase) (bool, error) {
+		_, rowIter, err := se.Query(ctx, "COMMIT;")
 		if err != nil {
 			return false, err
 		}
@@ -1213,7 +1073,7 @@ func flushBatchedEdits(ctx *sql.Context, se *sqlEngine) error {
 }
 
 // Processes a single query in batch mode. The Root of the sqlEngine may or may not be changed.
-func processBatchQuery(ctx *sql.Context, query string, se *sqlEngine) error {
+func processBatchQuery(ctx *sql.Context, query string, se *engine.SqlEngine) error {
 	sqlStatement, err := sqlparser.Parse(query)
 	if err == sqlparser.ErrEmpty {
 		// silently skip empty statements
@@ -1267,7 +1127,7 @@ func processBatchQuery(ctx *sql.Context, query string, se *sqlEngine) error {
 	return nil
 }
 
-func processNonBatchableQuery(ctx *sql.Context, se *sqlEngine, query string, sqlStatement sqlparser.Statement) (returnErr error) {
+func processNonBatchableQuery(ctx *sql.Context, se *engine.SqlEngine, query string, sqlStatement sqlparser.Statement) (returnErr error) {
 	sqlSch, rowIter, err := processQuery(ctx, query, se)
 	if err != nil {
 		return err
@@ -1287,7 +1147,7 @@ func processNonBatchableQuery(ctx *sql.Context, se *sqlEngine, query string, sql
 				cli.Print("\n")
 				displayStrLen = 0
 			}
-			err = PrettyPrintResults(ctx, se.resultFormat, sqlSch, rowIter, HasTopLevelOrderByClause(query))
+			err = engine.PrettyPrintResults(ctx, se.GetReturnFormat(), sqlSch, rowIter, HasTopLevelOrderByClause(query))
 			if err != nil {
 				return err
 			}
@@ -1303,8 +1163,8 @@ func processNonBatchableQuery(ctx *sql.Context, se *sqlEngine, query string, sql
 	return flushBatchedEdits(ctx, se)
 }
 
-func processBatchableEditQuery(ctx *sql.Context, se *sqlEngine, query string, sqlStatement sqlparser.Statement) (returnErr error) {
-	_, rowIter, err := se.query(ctx, query)
+func processBatchableEditQuery(ctx *sql.Context, se *engine.SqlEngine, query string, sqlStatement sqlparser.Statement) (returnErr error) {
+	_, rowIter, err := se.Query(ctx, query)
 	if err != nil {
 		return err
 	}
@@ -1332,7 +1192,7 @@ func processBatchableEditQuery(ctx *sql.Context, se *sqlEngine, query string, sq
 // canProcessBatchEdit returns whether the given statement can be processed as a batch insert. Only simple inserts
 // (inserting a list of values) and deletes can be processed in this way. Other kinds of insert (notably INSERT INTO
 // SELECT AS and AUTO_INCREMENT) need a flushed root and can't benefit from batch optimizations.
-func canProcessAsBatchEdit(ctx *sql.Context, sqlStatement sqlparser.Statement, se *sqlEngine, query string) (batchMode, error) {
+func canProcessAsBatchEdit(ctx *sql.Context, sqlStatement sqlparser.Statement, se *engine.SqlEngine, query string) (batchMode, error) {
 	switch s := sqlStatement.(type) {
 	case *sqlparser.Delete:
 		foundSubquery, err := checkForSubqueries(query)
@@ -1415,7 +1275,7 @@ func HasTopLevelOrderByClause(query string) bool {
 }
 
 // parses the query to check if it inserts into a table with AUTO_INCREMENT
-func insertsIntoAutoIncrementCol(ctx *sql.Context, se *sqlEngine, query string) (bool, error) {
+func insertsIntoAutoIncrementCol(ctx *sql.Context, se *engine.SqlEngine, query string) (bool, error) {
 	p, err := parse.Parse(ctx, query)
 	if err != nil {
 		return false, err
@@ -1425,7 +1285,7 @@ func insertsIntoAutoIncrementCol(ctx *sql.Context, se *sqlEngine, query string)
 		return false, nil
 	}
 
-	a, err := se.engine.Analyzer.Analyze(ctx, p, nil)
+	a, err := se.Analyze(ctx, p)
 	if err != nil {
 		return false, err
 	}
@@ -1489,248 +1349,3 @@ func mergeResultIntoStats(statement sqlparser.Statement, rowIter sql.RowIter, s
 		}
 	}
 }
-
-type sqlEngine struct {
-	dbs            map[string]dsqle.SqlDatabase
-	sess           *dsess.DoltSession
-	contextFactory func(ctx context.Context) (*sql.Context, error)
-	engine         *sqle.Engine
-	resultFormat   resultFormat
-}
-
-var ErrDBNotFoundKind = errors.NewKind("database '%s' not found")
-
-// sqlEngine packages up the context necessary to run sql queries against sqle.
-func newSqlEngine(
-	ctx context.Context,
-	config config.ReadWriteConfig,
-	fs filesys.Filesys,
-	format resultFormat,
-	initialDb string,
-	dbs ...dsqle.SqlDatabase,
-) (*sqlEngine, error) {
-	au := new(auth.None)
-
-	parallelism := runtime.GOMAXPROCS(0)
-
-	infoDB := information_schema.NewInformationSchemaDatabase()
-	all := append(dsqleDBsAsSqlDBs(dbs), infoDB)
-
-	pro := dsqle.NewDoltDatabaseProvider(config, fs, all...)
-
-	engine := sqle.New(analyzer.NewBuilder(pro).WithParallelism(parallelism).Build(), &sqle.Config{Auth: au})
-
-	if dbg, ok := os.LookupEnv("DOLT_SQL_DEBUG_LOG"); ok && strings.ToLower(dbg) == "true" {
-		engine.Analyzer.Debug = true
-		if verbose, ok := os.LookupEnv("DOLT_SQL_DEBUG_LOG_VERBOSE"); ok && strings.ToLower(verbose) == "true" {
-			engine.Analyzer.Verbose = true
-		}
-	}
-
-	nameToDB := make(map[string]dsqle.SqlDatabase)
-	var dbStates []dsess.InitialDbState
-	for _, db := range dbs {
-		nameToDB[db.Name()] = db
-
-		dbState, err := dsqle.GetInitialDBState(ctx, db)
-		if err != nil {
-			return nil, err
-		}
-
-		dbStates = append(dbStates, dbState)
-	}
-
-	sess, err := dsess.NewDoltSession(sql.NewEmptyContext(), sql.NewBaseSession(), pro, config, dbStates...)
-	if err != nil {
-		return nil, err
-	}
-
-	// this is overwritten only for server sessions
-	for _, db := range dbs {
-		db.DbData().Ddb.SetCommitHookLogger(ctx, cli.CliOut)
-	}
-
-	// TODO: this should just be the session default like it is with MySQL
-	err = sess.SetSessionVariable(sql.NewContext(ctx), sql.AutoCommitSessionVar, true)
-	if err != nil {
-		return nil, err
-	}
-
-	return &sqlEngine{
-		dbs:            nameToDB,
-		sess:           sess,
-		contextFactory: newSqlContext(sess, initialDb),
-		engine:         engine,
-		resultFormat:   format,
-	}, nil
-}
-
-func newSqlContext(sess *dsess.DoltSession, initialDb string) func(ctx context.Context) (*sql.Context, error) {
-	return func(ctx context.Context) (*sql.Context, error) {
-		sqlCtx := sql.NewContext(ctx,
-			sql.WithSession(sess),
-			sql.WithTracer(tracing.Tracer(ctx)))
-
-		// If the session was already updated with a database then continue using it in the new session. Otherwise
-		// use the initial one.
-		if sessionDB := sess.GetCurrentDatabase(); sessionDB != "" {
-			sqlCtx.SetCurrentDatabase(sessionDB)
-		} else {
-
-			sqlCtx.SetCurrentDatabase(initialDb)
-		}
-
-		return sqlCtx, nil
-	}
-}
-
-func dbsAsDSQLDBs(dbs []sql.Database) []dsqle.Database {
-	dsqlDBs := make([]dsqle.Database, 0, len(dbs))
-
-	for _, db := range dbs {
-		dsqlDB, ok := db.(dsqle.Database)
-
-		if ok {
-			dsqlDBs = append(dsqlDBs, dsqlDB)
-		}
-	}
-
-	return dsqlDBs
-}
-
-func dsqleDBsAsSqlDBs(dbs []dsqle.SqlDatabase) []sql.Database {
-	sqlDbs := make([]sql.Database, 0, len(dbs))
-	for _, db := range dbs {
-		sqlDbs = append(sqlDbs, db)
-	}
-	return sqlDbs
-}
-
-func getDbState(ctx context.Context, db dsqle.Database, mrEnv env.MultiRepoEnv) (dsess.InitialDbState, error) {
-	var dEnv *env.DoltEnv
-	mrEnv.Iter(func(name string, de *env.DoltEnv) (stop bool, err error) {
-		if name == db.Name() {
-			dEnv = de
-			return true, nil
-		}
-		return false, nil
-	})
-
-	if dEnv == nil {
-		return dsess.InitialDbState{}, fmt.Errorf("Couldn't find environment for database %s", db.Name())
-	}
-
-	head := dEnv.RepoStateReader().CWBHeadSpec()
-	headCommit, err := dEnv.DoltDB.Resolve(ctx, head, dEnv.RepoStateReader().CWBHeadRef())
-	if err != nil {
-		return dsess.InitialDbState{}, err
-	}
-
-	ws, err := dEnv.WorkingSet(ctx)
-	if err != nil {
-		return dsess.InitialDbState{}, err
-	}
-
-	return dsess.InitialDbState{
-		Db:         db,
-		HeadCommit: headCommit,
-		WorkingSet: ws,
-		DbData:     dEnv.DbData(),
-		Remotes:    dEnv.RepoState.Remotes,
-	}, nil
-}
-
-func (se *sqlEngine) iterDBs(cb func(name string, db dsqle.SqlDatabase) (stop bool, err error)) error {
-	for name, db := range se.dbs {
-		stop, err := cb(name, db)
-
-		if err != nil {
-			return err
-		}
-
-		if stop {
-			break
-		}
-	}
-
-	return nil
-}
-
-func (se *sqlEngine) getRoots(sqlCtx *sql.Context) (map[string]*doltdb.RootValue, error) {
-	newRoots := make(map[string]*doltdb.RootValue)
-	for name, db := range se.dbs {
-		var err error
-		newRoots[name], err = db.GetRoot(sqlCtx)
-
-		if err != nil {
-			return nil, err
-		}
-	}
-
-	return newRoots, nil
-}
-
-func (se *sqlEngine) newContext(ctx context.Context) (*sql.Context, error) {
-	return se.contextFactory(ctx)
-}
-
-// Execute a SQL statement and return values for printing.
-func (se *sqlEngine) query(ctx *sql.Context, query string) (sql.Schema, sql.RowIter, error) {
-	return se.engine.Query(ctx, query)
-}
-
-func (se *sqlEngine) dbddl(ctx *sql.Context, dbddl *sqlparser.DBDDL, query string) (sql.Schema, sql.RowIter, error) {
-	action := strings.ToLower(dbddl.Action)
-	var rowIter sql.RowIter = nil
-	var err error = nil
-
-	if action != sqlparser.CreateStr && action != sqlparser.DropStr {
-		return nil, nil, fmt.Errorf("Unhandled DBDDL action %v in query %v", action, query)
-	}
-
-	if action == sqlparser.DropStr {
-		// Should not be allowed to delete repo name and information schema
-		if dbddl.DBName == information_schema.InformationSchemaDatabaseName {
-			return nil, nil, fmt.Errorf("DROP DATABASE isn't supported for database %s", information_schema.InformationSchemaDatabaseName)
-		}
-	}
-
-	sch, rowIter, err := se.query(ctx, query)
-
-	if rowIter != nil {
-		err = rowIter.Close(ctx)
-		if err != nil {
-			return nil, nil, err
-		}
-	}
-
-	if err != nil {
-		return nil, nil, err
-	}
-
-	return sch, nil, nil
-}
-
-// Executes a SQL DDL statement (create, update, etc.). Updates the new root value in
-// the sqlEngine if necessary.
-func (se *sqlEngine) ddl(ctx *sql.Context, ddl *sqlparser.DDL, query string) (sql.Schema, sql.RowIter, error) {
-	switch ddl.Action {
-	case sqlparser.CreateStr, sqlparser.DropStr, sqlparser.AlterStr, sqlparser.RenameStr, sqlparser.TruncateStr:
-		_, ri, err := se.query(ctx, query)
-		if err == nil {
-			for _, err = ri.Next(); err == nil; _, err = ri.Next() {
-			}
-			if err == io.EOF {
-				err = ri.Close(ctx)
-			} else {
-				closeErr := ri.Close(ctx)
-				if closeErr != nil {
-					err = errhand.BuildDError("error while executing ddl").AddCause(err).AddCause(closeErr).Build()
-				}
-			}
-		}
-		return nil, nil, err
-	default:
-		return nil, nil, fmt.Errorf("Unhandled DDL action %v in query %v", ddl.Action, query)
-	}
-}
